==> create-gooddata-react-app-0.1.28-0.tgz: src/routes/Trend.js <==
import React, { useState } from "react";
import { Container, Row, Col } from "react-grid-system";
import { Model } from "@gooddata/react-components";

import C from "../constants";
import Page from "../components/Page";
import YearSelect from "../components/YearSelect";
import TrendWidget from "../components/visualizations/TrendWidget/TrendWidget";

import sharedStyles from "../shared.module.scss";

const Trend = () => {
    const [selectedYear, setSelectedYear] = useState(2017);
    const dateFilters = [
        Model.absoluteDateFilter(C.dateDataset, `${selectedYear}-01-01`, `${selectedYear}-12-31`),
    ];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Measure By Attribute Change Widget</h2>
                            <YearSelect value={selectedYear} onChange={setSelectedYear} />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col>
                        <TrendWidget
                            filters={dateFilters}
                            headline="Measure trends"
                            initialSelectedMeasuresIdentifiers={[
                                C.measures.grossProfit,
                                C.measures.totalSales,
                            ]}
                        />
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default Trend;

==> create-gooddata-react-app-0.1.31-0.tgz: src/routes/Trend.js <==
import React from "react";
import { Container, Row, Col } from "react-grid-system";

import C from "../constants";
import Page from "../components/Page";
import LoadableYearSelect from "../components/LoadableYearSelect";
import useYearFilter from "../hooks/useYearFilter";
import TrendWidget from "../components/visualizations/TrendWidget/TrendWidget";

import sharedStyles from "../shared.module.scss";

const Trend = () => {
    const [selectedYear, selectedYearFilter, setSelectedYear] = useYearFilter();

    const dateFilters = [selectedYearFilter];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Measure By Attribute Change Widget</h2>
                            <LoadableYearSelect
                                selectedYear={selectedYear}
                                setSelectedYear={setSelectedYear}
                            />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col>
                        <TrendWidget
                            filters={dateFilters}
                            headline="Measure trends"
                            initialSelectedMeasuresIdentifiers={[
                                C.measures.grossProfit,
                                C.measures.totalSales,
                            ]}
                        />
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default Trend;
